@@ -113,8 +113,10 @@ QString R_SPICE::netlist()
     return QString();
 }
 
-QString R_SPICE::spice_netlist(bool)
+QString R_SPICE::spice_netlist(spicecompat::SpiceDialect dialect /* = spicecompat::SPICEDefault */)
 {
+    Q_UNUSED(dialect);
+
     QString ltr = getProperty("Letter")->Value;
     QString s = spicecompat::check_refdes(Name,ltr);
     for (Port *p1 : Ports) {
@@ -129,12 +131,22 @@ QString R_SPICE::spice_netlist(bool)
     QString R_Line_4= Props.at(3)->Value;
     QString R_Line_5= Props.at(4)->Value;
 
-    if(  R.length()  > 0)          s += QString("%1").arg(R);
-    if(  R_Line_2.length() > 0 )   s += QString("\n%1").arg(R_Line_2);
-    if(  R_Line_3.length() > 0 )   s += QString("\n%1").arg(R_Line_3);
-    if(  R_Line_4.length() > 0 )   s += QString("\n%1").arg(R_Line_4);
-    if(  R_Line_5.length() > 0)    s += QString("\n%1").arg(R_Line_5);
+    if(  R.length()  > 0)          s += QStringLiteral("%1").arg(R);
+    if(  R_Line_2.length() > 0 )   s += QStringLiteral("\n%1").arg(R_Line_2);
+    if(  R_Line_3.length() > 0 )   s += QStringLiteral("\n%1").arg(R_Line_3);
+    if(  R_Line_4.length() > 0 )   s += QStringLiteral("\n%1").arg(R_Line_4);
+    if(  R_Line_5.length() > 0)    s += QStringLiteral("\n%1").arg(R_Line_5);
     s += "\n";
 
     return s;
 }
+
+QString R_SPICE::cdl_netlist()
+{
+    if (Ports.size() == 2)
+    {
+        return spice_netlist(spicecompat::CDL);
+    }
+
+    return QString();
+}
